# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.ssf_provider import SSFProvider

class TestSSFProvider(unittest.TestCase):
    """SSFProvider unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SSFProvider:
        """Test SSFProvider
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SSFProvider`
        """
        model = SSFProvider()
        if include_optional:
            return SSFProvider(
                pk = 56,
                name = '',
                component = '',
                verbose_name = '',
                verbose_name_plural = '',
                meta_model_name = '',
                signing_key = '',
                token_obj = authentik_client.models.token.Token(
                    pk = '', 
                    managed = '', 
                    identifier = 'z', 
                    intent = 'verification', 
                    user = 56, 
                    user_obj = null, 
                    description = '', 
                    expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    expiring = True, ),
                oidc_auth_providers = [
                    56
                    ],
                ssf_url = '',
                event_retention = ''
            )
        else:
            return SSFProvider(
                pk = 56,
                name = '',
                component = '',
                verbose_name = '',
                verbose_name_plural = '',
                meta_model_name = '',
                signing_key = '',
                token_obj = authentik_client.models.token.Token(
                    pk = '', 
                    managed = '', 
                    identifier = 'z', 
                    intent = 'verification', 
                    user = 56, 
                    user_obj = null, 
                    description = '', 
                    expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    expiring = True, ),
                ssf_url = '',
        )
        """

    def testSSFProvider(self):
        """Test SSFProvider"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.admin_api import AdminApi


class TestAdminApi(unittest.TestCase):
    """AdminApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AdminApi()

    def tearDown(self) -> None:
        pass

    def test_admin_apps_list(self) -> None:
        """Test case for admin_apps_list

        """
        pass

    def test_admin_models_list(self) -> None:
        """Test case for admin_models_list

        """
        pass

    def test_admin_settings_partial_update(self) -> None:
        """Test case for admin_settings_partial_update

        """
        pass

    def test_admin_settings_retrieve(self) -> None:
        """Test case for admin_settings_retrieve

        """
        pass

    def test_admin_settings_update(self) -> None:
        """Test case for admin_settings_update

        """
        pass

    def test_admin_system_create(self) -> None:
        """Test case for admin_system_create

        """
        pass

    def test_admin_system_retrieve(self) -> None:
        """Test case for admin_system_retrieve

        """
        pass

    def test_admin_version_history_list(self) -> None:
        """Test case for admin_version_history_list

        """
        pass

    def test_admin_version_history_retrieve(self) -> None:
        """Test case for admin_version_history_retrieve

        """
        pass

    def test_admin_version_retrieve(self) -> None:
        """Test case for admin_version_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()
